@@ -117,46 +117,47 @@ class HdlOpType(Enum):
     (Python equivalent of c++ hdlConvertor::hdlAst::HdlOpType)
     """
     (
-        RANGE,  # range used in VHDL type specifications
-        THROUGHOUT,  # SV throughout operator 
-        REFERENCE,
-        DEREFERENCE,
-        DEFINE_RESOLVER,  # used in resolver specification in vhdl subtype definition
-        TYPE_OF,  # SV type operator
-        INDEX,  # array index
-        PART_SELECT_POST, # logic [31: 0] a; logic [0 :31] b;  a[ 0 +: 8] == a[ 7 : 0]; b[ 0 +: 8] == b[0 : 7]
-        PART_SELECT_PRE, # a[15 -: 8] == a[15 : 8]; b[15 -: 8] == b[8 :15]
-        DOWNTO,  # downto for the slice specification
-        TO,  # to for the slice specification
+        # arithmetic
         MINUS_UNARY,
         PLUS_UNARY,
-        OR_UNARY,  # SV or reduction (|a)
-        AND_UNARY,  # SV and reduction (&a)
-        NAND_UNARY,  # SV nand reduction (~&a)
-        NOR_UNARY,  # SV nor reduction (~|a)
-        XOR_UNARY,  # SV xor reduction (^a)
-        XNOR_UNARY,  # SV and reduction (~^a) or (^~a)
-        SUB,
-        ADD,
-        DIV,
-        MUL,
-        MOD,  # modulo
-        REM,  # reminder
-        CONCAT,  # concatenation of signals
-        REPL_CONCAT,  # replicative concatenation {<N>, <item>}
-                 # duplicates and concatenates the item N times
-        POW,  # power of
-        ABS,  # absolute value
-        NEG_LOG,  # logical negation "not" in vhdl
+        SUB, # -
+        ADD, # +
+        DIV, # /
+        MUL, # *
+        MOD, # % modulo
+        REM, # remainder
+        POW, # power of
+        ABS, # absolute value
+        INCR_PRE,  # ++x
+        DECR_PRE,  # --x
+        INCR_POST,  # x--
+        DECR_POST,  # x++
+        # bitwise log. operators
+        NEG_LOG,  # ~, logical negation "not" in vhdl
         NEG,  # bitwise negation
-        AND_LOG,  # "and" in vhdl
-        OR_LOG,  # "or" in vhdl
+        AND_LOG,  # "and" in vhdl, &&
+        OR_LOG,  # "or" in vhdl, ||
         AND,  # & in vhdl
         OR,  # | in vhdl
         NAND,
         NOR,
         XOR,
         XNOR,
+        # SV reduction operators
+        OR_UNARY,  # or reduction (|a)
+        AND_UNARY,  # and reduction (&a)
+        NAND_UNARY,  # nand reduction (~&a)
+        NOR_UNARY,  # nor reduction (~|a)
+        XOR_UNARY,  # xor reduction (^a)
+        XNOR_UNARY,  # and reduction (~^a) or (^~a)
+        # shifts
+        SLL,  # shift left logical
+        SRL,  # shift right logical
+        SLA,  # shift left arithmetical
+        SRA,  # shift right arithmetical
+        ROL,  # rotate left
+        ROR,  # rotate right
+        # comparison operators
         EQ,  # ==
         NE,  # !=
         IS,  # ===
@@ -165,22 +166,6 @@ class HdlOpType(Enum):
         LE,   # <=
         GT,  # >
         GE,  # >=
-        SLL,  # shift left logical
-        SRL,  # shift right logical
-        SLA,  # shift left arithmetical
-        SRA,  # shift right arithmetical
-        ROL,  # rotate left
-        ROR,  # rotate right
-        TERNARY,
-        DOT,  # accessing of property
-        DOUBLE_COLON,  # ::, SV accessing class/package static property/type
-        APOSTROPHE,  # vhdl attribute access
-        CALL,  # call of HDL function
-        PARAMETRIZATION,  # specification of template arguments
-        ARROW,  # arrow operator used in vhdl type descriptions
-        RISING,  # rising edge/posedge event operator
-        FALLING,  # falling edge/negedge event operator
-        MAP_ASSOCIATION,
         # VHDL-2008 matching ops (the X values are ignored while match)
         EQ_MATCH, # SV ==?
         NE_MATCH, # SV !=?
@@ -188,10 +173,21 @@ class HdlOpType(Enum):
         LE_MATCH,
         GT_MATCH,
         GE_MATCH,
-        INCR_PRE,  # ++x
-        DECR_PRE,  # --x
-        INCR_POST,  # x--
-        DECR_POST,  # x++
+        # member accessing
+        INDEX,  # array index
+        CONCAT,  # concatenation of signals
+        REPL_CONCAT,  # replicative concatenation {<N>, <item>}
+                      # duplicates and concatenates the item N times
+        PART_SELECT_POST, # logic [31: 0] a; logic [0 :31] b;  a[ 0 +: 8] == a[ 7 : 0]; b[ 0 +: 8] == b[0 : 7]
+        PART_SELECT_PRE, # a[15 -: 8] == a[15 : 8]; b[15 -: 8] == b[8 :15]
+        DOT,  # accessing of property
+        DOUBLE_COLON,  # ::, SV accessing class/package static property/type
+        APOSTROPHE,  # vhdl attribute access
+        ARROW,  # pointer member access, VHDL arrow operator used in type descriptions
+        REFERENCE,
+        DEREFERENCE,
+        
+        # assignment operators
         ASSIGN,  # =
         PLUS_ASSIGN,  # +=
         MINUS_ASSIGN,  # -=
@@ -205,7 +201,21 @@ class HdlOpType(Enum):
         SHIFT_RIGHT_ASSIGN,  # >>=
         ARITH_SHIFT_LEFT_ASSIGN,  # <<<=
         ARITH_SHIFT_RIGHT_ASSIGN,  # >>>=
-    ) = range(86)
+        
+        TERNARY, # cond ? a:b, a if cond else b 
+        CALL,  # call of HDL function
+        RISING,  # rising edge/posedge event operator
+        FALLING,  # falling edge/negedge event operator
+        DOWNTO,  # downto for the slice specification
+        TO,  # to for the slice specification
+        PARAMETRIZATION,  # specification of template arguments
+        MAP_ASSOCIATION, # arg=val
+        RANGE,  # range used in VHDL type specifications
+        THROUGHOUT,  # SV throughout operator 
+        DEFINE_RESOLVER,  # used in resolver specification in vhdl subtype definition
+        TYPE_OF,  # SV type operator
+        UNIT_SPEC, # vhdl unit specification eg. 10 ns
+    ) = range(87)
     # note that in verilog bitewise operators can have only one argument
 
 
