@@ -1,5 +1,5 @@
 from hdlConvertorAst.hdlAst import HdlDirection, HdlValueId, HdlValueInt, \
-    HdlOp, HdlAll, HdlTypeAuto, HdlOthers, HdlTypeType
+    HdlOp, NON_INSTANCIABLE_NODES
 from hdlConvertorAst.py_ver_compatibility import is_str
 from hdlConvertorAst.to.hdl_ast_visitor import HdlAstVisitor
 from hdlConvertorAst.hdlAst._typeDefs import iHdlTypeDef
@@ -165,6 +165,15 @@ class ToJson(HdlAstVisitor):
         d["is_packed"] = o.is_packed
         return d
 
+    def visit_HdlPhysicalDef(self, o):
+        """
+        :type o: HdlPhysicalDef
+        """
+        d = self.visit_iHdlObjWithName(o)
+        d["range"] = self.visit_iHdlExpr(o.range)
+        d["members"] = [self.visit_iHdlExpr(v) for v in o.members]
+        return d
+    
     def visit_HdlEnumDef(self, o):
         """
         :type o: HdlEnumDef
@@ -328,13 +337,6 @@ class ToJson(HdlAstVisitor):
             d = self.visit_HdlValueInt(o)
         elif isinstance(o, HdlOp):
             d = self.visit_HdlOp(o)
-        elif o is HdlAll or\
-                o is HdlTypeAuto or\
-                o is HdlOthers or\
-                o is HdlTypeType:
-            d = {
-                "__class__": o.__name__,
-            }
         elif isinstance(o, (list, tuple, dict)):
             if isinstance(o, dict):
                 items = []
@@ -351,6 +353,12 @@ class ToJson(HdlAstVisitor):
             }
         elif isinstance(o, iHdlTypeDef):
             return HdlAstVisitor.visit_iHdlObj(self, o)
+        elif isinstance(o, float):
+            return o
+        elif o in NON_INSTANCIABLE_NODES:
+            d = {
+                "__class__": o.__name__,
+            }
         else:
             raise NotImplementedError(
                 "Unexpected object of type " + str(type(o)))
