@@ -1,6 +1,6 @@
 from hdlConvertorAst.hdlAst import HdlDirection, iHdlStatement, \
     HdlIdDef, HdlModuleDec, HdlFunctionDef, HdlCompInst, \
-    HdlTypeType, HdlOp, HdlOpType, HdlValueIdspace, \
+    HdlTypeType, HdlOp, HdlOpType, HdlValueIdspace, HdlPhysicalDef, \
     HdlEnumDef, HdlTypeSubtype, HdlValueInt, HdlClassDef, HdlClassType
 from hdlConvertorAst.to.hdlUtils import Indent, iter_with_last, UnIndent
 from hdlConvertorAst.to.vhdl.stm import ToVhdl2008Stm
@@ -217,16 +217,25 @@ class ToVhdl2008(ToVhdl2008Stm):
                 if isinstance(_t, HdlEnumDef):
                     self.visit_HdlEnumDef(_t)
                 elif isinstance(_t, HdlOp):
-                    assert _t.fn == HdlOpType.INDEX, _t.fn
-                    w("ARRAY (")
-                    for last, i in iter_with_last(_t.ops[1:]):
-                        self.visit_iHdlExpr(i)
-                        if not last:
-                            w(", ")
-                    w(") OF ")
-                    self.visit_iHdlExpr(_t.ops[0])
+                    if _t.fn == HdlOpType.INDEX:
+                        w("ARRAY (")
+                        for last, i in iter_with_last(_t.ops[1:]):
+                            self.visit_iHdlExpr(i)
+                            if not last:
+                                w(", ")
+                        w(") OF ")
+                        self.visit_iHdlExpr(_t.ops[0])
+                    elif _t.fn == HdlOpType.RANGE:
+                        w("RANGE ")
+                        assert len(_t.ops) == 1, _t.ops
+                        self.visit_iHdlExpr(_t.ops[0])
+                    else:
+                        raise NotImplementedError(_t.fn)
+
                 elif isinstance(_t, HdlClassDef):
                     self.visit_HdlClassDef(_t)
+                elif isinstance(_t, HdlPhysicalDef):
+                    self.visit_HdlPhysicalDef(_t)
                 else:
                     raise NotImplementedError(type(_t))
             finally:
@@ -273,6 +282,24 @@ class ToVhdl2008(ToVhdl2008Stm):
                 self.visit_HdlIdDef(m)
         w("END RECORD")
 
+    def visit_HdlPhysicalDef(self, o):
+        """
+        :type o: HdlPhysicalDef
+        """
+        w = self.out.write
+        self.visit_HdlOp(o.range)
+        w("\n")
+        with Indent(self.out):
+            w("UNITS\n")
+            with Indent(self.out):
+                for k, v in o.members:
+                    w(k)
+                    if v is not None:
+                        w(" = ")
+                        self.visit_HdlOp(v)
+                    w(";\n")
+            w("END UNITS")
+
     def visit_HdlEnumDef(self, o):
         """
         :type o: HdlEnumDef
